@@ -543,13 +543,20 @@ def list_inheritable(p=0):
 def methods_inherited(base_class, p=0):
     class Base:
         pass
-
     class A(base_class):
         pass
-
     returned_set = set(dir(A)) - set(dir(Base))
+    try:
+        abstract_methods = A.__abstractmethods__
+    except:
+        abstract_methods = None
     if p == 1:
         from pprint import pprint
         pprint(returned_set, compact=True, width=120)
+        if abstract_methods:
+            pprint({'__abstractmethods__': abstract_methods}, compact=True, width=120)
     else:
-        return returned_set
\ No newline at end of file
+        if abstract_methods:
+            return returned_set, {'__abstractmethods__': abstract_methods}
+        else:
+            return returned_set
\ No newline at end of file
